@@ -49,8 +49,8 @@
 #' ## ------------------------------------------------------------
 #' ## -------- iris data
 #' ## iris
-#' #rfsrc_iris <- rfsrc(Species ~., data = iris)
-#' data(rfsrc_iris, package="ggRandomForests")
+#'  rfsrc_iris <- rfsrc(Species ~., data = iris)
+#' #data(rfsrc_iris, package="ggRandomForests")
 #' 
 #' gg_dta <- gg_variable(rfsrc_iris)
 #' plot(gg_dta, xvar="Sepal.Width")
@@ -186,8 +186,8 @@ gg_variable.rfsrc <- function(object,
     gg_dta$yvar <- object$yvar
     
   }else if(object$family == "surv"){
-    gg_dta$cens <- as.logical(object$yvar[,2])
-    colnames(gg_dta) <- c(object$xvar.names, "cens")
+    gg_dta$event <- as.logical(object$yvar[,2])
+    colnames(gg_dta) <- c(object$xvar.names, "event")
     
     if(is.null(time)) time <- median(object$time.interest)
     lng <- length(time)
@@ -251,15 +251,15 @@ gg_variable.randomForest <- function(object,
   
   if(object$type == "regression"){
     gg_dta$yhat <- object$predicted
-
+    
   }else{ # if(object$family == "class"){
-      colnames(object$predicted) <- paste("yhat.", colnames(object$predicted),
-                                          sep="")
-      gg_dta <- object$predicted
+    colnames(object$predicted) <- paste("yhat.", colnames(object$predicted),
+                                        sep="")
+    gg_dta <- object$predicted
     
     gg_dta$yvar <- object$yvar
     
   }
   class(gg_dta) <- c("gg_variable", object$type, class(gg_dta))
   invisible(gg_dta)
-}
+}
\ No newline at end of file
